@@ -64,7 +64,7 @@ namespace QuantLib {
     }
 
     bool CashFlows::isExpired(const Leg& leg,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate)
     {
         if (leg.empty())
@@ -82,7 +82,7 @@ namespace QuantLib {
 
     Leg::const_reverse_iterator
     CashFlows::previousCashFlow(const Leg& leg,
-                                bool includeSettlementDateFlows,
+                                const ext::optional<bool>& includeSettlementDateFlows,
                                 Date settlementDate) {
         if (leg.empty())
             return leg.rend();
@@ -100,7 +100,7 @@ namespace QuantLib {
 
     Leg::const_iterator
     CashFlows::nextCashFlow(const Leg& leg,
-                            bool includeSettlementDateFlows,
+                            const ext::optional<bool>& includeSettlementDateFlows,
                             Date settlementDate) {
         if (leg.empty())
             return leg.end();
@@ -117,7 +117,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::previousCashFlowDate(const Leg& leg,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows,
                                          Date settlementDate) {
         Leg::const_reverse_iterator cf;
         cf = previousCashFlow(leg, includeSettlementDateFlows, settlementDate);
@@ -129,7 +129,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::nextCashFlowDate(const Leg& leg,
-                                     bool includeSettlementDateFlows,
+                                     const ext::optional<bool>& includeSettlementDateFlows,
                                      Date settlementDate) {
         Leg::const_iterator cf;
         cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
@@ -141,7 +141,7 @@ namespace QuantLib {
     }
 
     Real CashFlows::previousCashFlowAmount(const Leg& leg,
-                                           bool includeSettlementDateFlows,
+                                           const ext::optional<bool>& includeSettlementDateFlows,
                                            Date settlementDate) {
         Leg::const_reverse_iterator cf;
         cf = previousCashFlow(leg, includeSettlementDateFlows, settlementDate);
@@ -157,7 +157,7 @@ namespace QuantLib {
     }
 
     Real CashFlows::nextCashFlowAmount(const Leg& leg,
-                                       bool includeSettlementDateFlows,
+                                       const ext::optional<bool>& includeSettlementDateFlows,
                                        Date settlementDate) {
         Leg::const_iterator cf;
         cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
@@ -176,8 +176,7 @@ namespace QuantLib {
     namespace {
 
         template<typename Iter>
-        Rate aggregateRate(const Leg& leg,
-                           Iter first,
+        Rate aggregateRate(Iter first,
                            const Iter& last) {
             if (first==last) return 0.0;
 
@@ -213,24 +212,24 @@ namespace QuantLib {
     } // anonymous namespace ends here
 
     Rate CashFlows::previousCouponRate(const Leg& leg,
-                                       bool includeSettlementDateFlows,
+                                       const ext::optional<bool>& includeSettlementDateFlows,
                                        Date settlementDate) {
         Leg::const_reverse_iterator cf;
         cf = previousCashFlow(leg, includeSettlementDateFlows, settlementDate);
 
-        return aggregateRate<Leg::const_reverse_iterator>(leg, cf, leg.rend());
+        return aggregateRate(cf, leg.rend());
     }
 
     Rate CashFlows::nextCouponRate(const Leg& leg,
-                                   bool includeSettlementDateFlows,
+                                   const ext::optional<bool>& includeSettlementDateFlows,
                                    Date settlementDate) {
         Leg::const_iterator cf;
         cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
-        return aggregateRate<Leg::const_iterator>(leg, cf, leg.end());
+        return aggregateRate(cf, leg.end());
     }
 
     Real CashFlows::nominal(const Leg& leg,
-                            bool includeSettlementDateFlows,
+                            const ext::optional<bool>& includeSettlementDateFlows,
                             Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end()) return 0.0;
@@ -245,7 +244,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::accrualStartDate(const Leg& leg,
-                                     bool includeSettlementDateFlows,
+                                     const ext::optional<bool>& includeSettlementDateFlows,
                                      Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end())
@@ -261,7 +260,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::accrualEndDate(const Leg& leg,
-                                   bool includeSettlementDateFlows,
+                                   const ext::optional<bool>& includeSettlementDateFlows,
                                    Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end())
@@ -277,7 +276,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::referencePeriodStart(const Leg& leg,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows,
                                          Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end())
@@ -293,7 +292,7 @@ namespace QuantLib {
     }
 
     Date CashFlows::referencePeriodEnd(const Leg& leg,
-                                       bool includeSettlementDateFlows,
+                                       const ext::optional<bool>& includeSettlementDateFlows,
                                        Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end())
@@ -309,7 +308,7 @@ namespace QuantLib {
     }
 
     Time CashFlows::accrualPeriod(const Leg& leg,
-                                  bool includeSettlementDateFlows,
+                                  const ext::optional<bool>& includeSettlementDateFlows,
                                   Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end()) return 0;
@@ -324,7 +323,7 @@ namespace QuantLib {
     }
 
     Date::serial_type CashFlows::accrualDays(const Leg& leg,
-                                             bool includeSettlementDateFlows,
+                                             const ext::optional<bool>& includeSettlementDateFlows,
                                              Date settlementDate) {
         auto cf = nextCashFlow(leg, includeSettlementDateFlows, settlementDate);
         if (cf==leg.end()) return 0;
@@ -339,7 +338,7 @@ namespace QuantLib {
     }
 
     Time CashFlows::accruedPeriod(const Leg& leg,
-                                  bool includeSettlementDateFlows,
+                                  const ext::optional<bool>& includeSettlementDateFlows,
                                   Date settlementDate) {
         if (settlementDate == Date())
             settlementDate = Settings::instance().evaluationDate();
@@ -357,7 +356,7 @@ namespace QuantLib {
     }
 
     Date::serial_type CashFlows::accruedDays(const Leg& leg,
-                                             bool includeSettlementDateFlows,
+                                             const ext::optional<bool>& includeSettlementDateFlows,
                                              Date settlementDate) {
         if (settlementDate == Date())
             settlementDate = Settings::instance().evaluationDate();
@@ -375,7 +374,7 @@ namespace QuantLib {
     }
 
     Real CashFlows::accruedAmount(const Leg& leg,
-                                  bool includeSettlementDateFlows,
+                                  const ext::optional<bool>& includeSettlementDateFlows,
                                   Date settlementDate) {
         if (settlementDate == Date())
             settlementDate = Settings::instance().evaluationDate();
@@ -424,7 +423,7 @@ namespace QuantLib {
 
     Real CashFlows::npv(const Leg& leg,
                         const YieldTermStructure& discountCurve,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
 
@@ -449,7 +448,7 @@ namespace QuantLib {
 
     Real CashFlows::bps(const Leg& leg,
                         const YieldTermStructure& discountCurve,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
         if (leg.empty())
@@ -472,7 +471,7 @@ namespace QuantLib {
 
     std::pair<Real, Real> CashFlows::npvbps(const Leg& leg,
                                             const YieldTermStructure& discountCurve,
-                                            bool includeSettlementDateFlows,
+                                            const ext::optional<bool>& includeSettlementDateFlows,
                                             Date settlementDate,
                                             Date npvDate) {
         Real npv = 0.0;
@@ -509,7 +508,7 @@ namespace QuantLib {
 
     Rate CashFlows::atmRate(const Leg& leg,
                             const YieldTermStructure& discountCurve,
-                            bool includeSettlementDateFlows,
+                            const ext::optional<bool>& includeSettlementDateFlows,
                             Date settlementDate,
                             Date npvDate,
                             Real targetNpv) {
@@ -602,7 +601,7 @@ namespace QuantLib {
 
         Real simpleDuration(const Leg& leg,
                             const InterestRate& y,
-                            bool includeSettlementDateFlows,
+                            const ext::optional<bool>& includeSettlementDateFlows,
                             Date settlementDate,
                             Date npvDate) {
             if (leg.empty())
@@ -642,7 +641,7 @@ namespace QuantLib {
 
         Real modifiedDuration(const Leg& leg,
                               const InterestRate& y,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate,
                               Date npvDate) {
             if (leg.empty())
@@ -709,7 +708,7 @@ namespace QuantLib {
 
         Real macaulayDuration(const Leg& leg,
                               const InterestRate& y,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate,
                               Date npvDate) {
 
@@ -736,7 +735,7 @@ namespace QuantLib {
                                     DayCounter dayCounter,
                                     Compounding comp,
                                     Frequency freq,
-                                    bool includeSettlementDateFlows,
+                                    const ext::optional<bool>& includeSettlementDateFlows,
                                     Date settlementDate,
                                     Date npvDate)
     : leg_(leg), npv_(npv), dayCounter_(std::move(dayCounter)), compounding_(comp),
@@ -811,7 +810,7 @@ namespace QuantLib {
 
     Real CashFlows::npv(const Leg& leg,
                         const InterestRate& y,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
 
@@ -858,7 +857,7 @@ namespace QuantLib {
                         const DayCounter& dc,
                         Compounding comp,
                         Frequency freq,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
         return npv(leg, InterestRate(yield, dc, comp, freq),
@@ -868,7 +867,7 @@ namespace QuantLib {
 
     Real CashFlows::bps(const Leg& leg,
                         const InterestRate& yield,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
 
@@ -893,7 +892,7 @@ namespace QuantLib {
                         const DayCounter& dc,
                         Compounding comp,
                         Frequency freq,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
         return bps(leg, InterestRate(yield, dc, comp, freq),
@@ -906,7 +905,7 @@ namespace QuantLib {
                           const DayCounter& dayCounter,
                           Compounding compounding,
                           Frequency frequency,
-                          bool includeSettlementDateFlows,
+                          const ext::optional<bool>& includeSettlementDateFlows,
                           Date settlementDate,
                           Date npvDate,
                           Real accuracy,
@@ -925,7 +924,7 @@ namespace QuantLib {
     Time CashFlows::duration(const Leg& leg,
                              const InterestRate& rate,
                              Duration::Type type,
-                             bool includeSettlementDateFlows,
+                             const ext::optional<bool>& includeSettlementDateFlows,
                              Date settlementDate,
                              Date npvDate) {
 
@@ -962,7 +961,7 @@ namespace QuantLib {
                              Compounding comp,
                              Frequency freq,
                              Duration::Type type,
-                             bool includeSettlementDateFlows,
+                             const ext::optional<bool>& includeSettlementDateFlows,
                              Date settlementDate,
                              Date npvDate) {
         return duration(leg, InterestRate(yield, dc, comp, freq),
@@ -973,7 +972,7 @@ namespace QuantLib {
 
     Real CashFlows::convexity(const Leg& leg,
                               const InterestRate& y,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate,
                               Date npvDate) {
         if (leg.empty())
@@ -1047,7 +1046,7 @@ namespace QuantLib {
                               const DayCounter& dc,
                               Compounding comp,
                               Frequency freq,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate,
                               Date npvDate) {
         return convexity(leg, InterestRate(yield, dc, comp, freq),
@@ -1057,7 +1056,7 @@ namespace QuantLib {
 
     Real CashFlows::basisPointValue(const Leg& leg,
                                     const InterestRate& y,
-                                    bool includeSettlementDateFlows,
+                                    const ext::optional<bool>& includeSettlementDateFlows,
                                     Date settlementDate,
                                     Date npvDate) {
         if (leg.empty())
@@ -1094,7 +1093,7 @@ namespace QuantLib {
                                     const DayCounter& dc,
                                     Compounding comp,
                                     Frequency freq,
-                                    bool includeSettlementDateFlows,
+                                    const ext::optional<bool>& includeSettlementDateFlows,
                                     Date settlementDate,
                                     Date npvDate) {
         return basisPointValue(leg, InterestRate(yield, dc, comp, freq),
@@ -1104,7 +1103,7 @@ namespace QuantLib {
 
     Real CashFlows::yieldValueBasisPoint(const Leg& leg,
                                          const InterestRate& y,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows,
                                          Date settlementDate,
                                          Date npvDate) {
         if (leg.empty())
@@ -1133,7 +1132,7 @@ namespace QuantLib {
                                          const DayCounter& dc,
                                          Compounding comp,
                                          Frequency freq,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows,
                                          Date settlementDate,
                                          Date npvDate) {
         return yieldValueBasisPoint(leg, InterestRate(yield, dc, comp, freq),
@@ -1142,62 +1141,13 @@ namespace QuantLib {
     }
 
     // Z-spread utility functions
-    namespace {
-
-        class ZSpreadFinder {
-          public:
-            ZSpreadFinder(const Leg& leg,
-                          const ext::shared_ptr<YieldTermStructure>& discountCurve,
-                          Real npv,
-                          const DayCounter& dc,
-                          Compounding comp,
-                          Frequency freq,
-                          bool includeSettlementDateFlows,
-                          Date settlementDate,
-                          Date npvDate)
-            : leg_(leg), npv_(npv), zSpread_(new SimpleQuote(0.0)),
-              curve_(Handle<YieldTermStructure>(discountCurve),
-                     Handle<Quote>(zSpread_), comp, freq, dc),
-              includeSettlementDateFlows_(includeSettlementDateFlows),
-              settlementDate_(settlementDate),
-              npvDate_(npvDate) {
-
-                if (settlementDate_ == Date())
-                    settlementDate_ = Settings::instance().evaluationDate();
-
-                if (npvDate_ == Date())
-                    npvDate_ = settlementDate_;
-
-                // if the discount curve allows extrapolation, let's
-                // the spreaded curve do too.
-                curve_.enableExtrapolation(
-                                  discountCurve->allowsExtrapolation());
-            }
-            Real operator()(Rate zSpread) const {
-                zSpread_->setValue(zSpread);
-                Real NPV = CashFlows::npv(leg_, curve_,
-                                          includeSettlementDateFlows_,
-                                          settlementDate_, npvDate_);
-                return npv_ - NPV;
-            }
-          private:
-            const Leg& leg_;
-            Real npv_;
-            ext::shared_ptr<SimpleQuote> zSpread_;
-            ZeroSpreadedTermStructure curve_;
-            bool includeSettlementDateFlows_;
-            Date settlementDate_, npvDate_;
-        };
-
-    } // anonymous namespace ends here
-
     Real CashFlows::npv(const Leg& leg,
                         const ext::shared_ptr<YieldTermStructure>& discountCurve,
                         Spread zSpread,
                         const DayCounter& dc,
                         Compounding comp,
                         Frequency freq,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows,
                         Date settlementDate,
                         Date npvDate) {
 
@@ -1216,9 +1166,7 @@ namespace QuantLib {
 
         ZeroSpreadedTermStructure spreadedCurve(discountCurveHandle,
                                                 zSpreadQuoteHandle,
-                                                comp, freq, dc);
-
-        spreadedCurve.enableExtrapolation(discountCurveHandle->allowsExtrapolation());
+                                                comp, freq);
 
         return npv(leg, spreadedCurve,
                    includeSettlementDateFlows,
@@ -1231,7 +1179,7 @@ namespace QuantLib {
                               const DayCounter& dayCounter,
                               Compounding compounding,
                               Frequency frequency,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows,
                               Date settlementDate,
                               Date npvDate,
                               Real accuracy,
@@ -1244,13 +1192,21 @@ namespace QuantLib {
         if (npvDate == Date())
             npvDate = settlementDate;
 
+        auto zSpreadQuote = ext::make_shared<SimpleQuote>();
+        ZeroSpreadedTermStructure spreadedCurve(Handle<YieldTermStructure>(discount),
+                                                Handle<Quote>(zSpreadQuote),
+                                                compounding,
+                                                frequency);
+        auto objFunction = [&](Rate zSpread) {
+            zSpreadQuote->setValue(zSpread);
+            Real NPV = CashFlows::npv(leg, spreadedCurve,
+                                      includeSettlementDateFlows,
+                                      settlementDate, npvDate);
+            return npv - NPV;
+        };
+
         Brent solver;
         solver.setMaxEvaluations(maxIterations);
-        ZSpreadFinder objFunction(leg,
-                                  discount,
-                                  npv,
-                                  dayCounter, compounding, frequency, includeSettlementDateFlows,
-                                  settlementDate, npvDate);
         Real step = 0.01;
         return solver.solve(objFunction, accuracy, guess, step);
     }
