@@ -47,7 +47,7 @@ namespace QuantLib {
                       DayCounter dayCounter,
                       Compounding comp,
                       Frequency freq,
-                      bool includeSettlementDateFlows,
+                      const ext::optional<bool>& includeSettlementDateFlows,
                       Date settlementDate,
                       Date npvDate);
 
@@ -61,7 +61,7 @@ namespace QuantLib {
             DayCounter dayCounter_;
             Compounding compounding_;
             Frequency frequency_;
-            bool includeSettlementDateFlows_;
+            ext::optional<bool> includeSettlementDateFlows_;
             Date settlementDate_, npvDate_;
         };
       public:
@@ -77,7 +77,7 @@ namespace QuantLib {
         static Date startDate(const Leg& leg);
         static Date maturityDate(const Leg& leg);
         static bool isExpired(const Leg& leg,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                               Date settlementDate = Date());
         //@}
 
@@ -86,28 +86,28 @@ namespace QuantLib {
         //! the last cashflow paying before or at the given date
         static Leg::const_reverse_iterator
         previousCashFlow(const Leg& leg,
-                         bool includeSettlementDateFlows,
+                         const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                          Date settlementDate = Date());
         //! the first cashflow paying after the given date
         static Leg::const_iterator
         nextCashFlow(const Leg& leg,
-                     bool includeSettlementDateFlows,
+                     const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                      Date settlementDate = Date());
         static Date
         previousCashFlowDate(const Leg& leg,
-                             bool includeSettlementDateFlows,
+                             const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                              Date settlementDate = Date());
         static Date
         nextCashFlowDate(const Leg& leg,
-                         bool includeSettlementDateFlows,
+                         const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                          Date settlementDate = Date());
         static Real
         previousCashFlowAmount(const Leg& leg,
-                               bool includeSettlementDateFlows,
+                               const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                Date settlementDate = Date());
         static Real
         nextCashFlowAmount(const Leg& leg,
-                           bool includeSettlementDateFlows,
+                           const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                            Date settlementDate = Date());
         //@}
 
@@ -115,52 +115,52 @@ namespace QuantLib {
         //@{
         static Rate
         previousCouponRate(const Leg& leg,
-                           bool includeSettlementDateFlows,
+                           const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                            Date settlementDate = Date());
         static Rate
         nextCouponRate(const Leg& leg,
-                       bool includeSettlementDateFlows,
+                       const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                        Date settlementDate = Date());
 
         static Real
         nominal(const Leg& leg,
-                bool includeSettlementDateFlows,
-                Date settlDate = Date());
+                const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
+                Date settlementDate = Date());
         static Date
         accrualStartDate(const Leg& leg,
-                         bool includeSettlementDateFlows,
-                         Date settlDate = Date());
+                         const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
+                         Date settlementDate = Date());
         static Date
         accrualEndDate(const Leg& leg,
-                       bool includeSettlementDateFlows,
+                       const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                        Date settlementDate = Date());
         static Date
         referencePeriodStart(const Leg& leg,
-                             bool includeSettlementDateFlows,
-                             Date settlDate = Date());
+                             const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
+                             Date settlementDate = Date());
         static Date
         referencePeriodEnd(const Leg& leg,
-                           bool includeSettlementDateFlows,
-                           Date settlDate = Date());
+                           const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
+                           Date settlementDate = Date());
         static Time
         accrualPeriod(const Leg& leg,
-                      bool includeSettlementDateFlows,
+                      const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                       Date settlementDate = Date());
         static Date::serial_type
         accrualDays(const Leg& leg,
-                    bool includeSettlementDateFlows,
+                    const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                     Date settlementDate = Date());
         static Time
         accruedPeriod(const Leg& leg,
-                      bool includeSettlementDateFlows,
+                      const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                       Date settlementDate = Date());
         static Date::serial_type
         accruedDays(const Leg& leg,
-                    bool includeSettlementDateFlows,
+                    const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                     Date settlementDate = Date());
         static Real
         accruedAmount(const Leg& leg,
-                      bool includeSettlementDateFlows,
+                      const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                       Date settlementDate = Date());
         //@}
 
@@ -172,7 +172,7 @@ namespace QuantLib {
         */
         static Real npv(const Leg& leg,
                         const YieldTermStructure& discountCurve,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         //! Basis-point sensitivity of the cash flows.
@@ -183,7 +183,7 @@ namespace QuantLib {
         */
         static Real bps(const Leg& leg,
                         const YieldTermStructure& discountCurve,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
 
@@ -193,7 +193,7 @@ namespace QuantLib {
         */
         static std::pair<Real, Real> npvbps(const Leg& leg,
                                             const YieldTermStructure& discountCurve,
-                                            bool includeSettlementDateFlows,
+                                            const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                             Date settlementDate = Date(),
                                             Date npvDate = Date());
 
@@ -205,7 +205,7 @@ namespace QuantLib {
         */
         static Rate atmRate(const Leg& leg,
                             const YieldTermStructure& discountCurve,
-                            bool includeSettlementDateFlows,
+                            const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                             Date settlementDate = Date(),
                             Date npvDate = Date(),
                             Real npv = Null<Real>());
@@ -224,7 +224,7 @@ namespace QuantLib {
         */
         static Real npv(const Leg& leg,
                         const InterestRate& yield,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         static Real npv(const Leg& leg,
@@ -232,7 +232,7 @@ namespace QuantLib {
                         const DayCounter& dayCounter,
                         Compounding compounding,
                         Frequency frequency,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         //! Basis-point sensitivity of the cash flows.
@@ -245,7 +245,7 @@ namespace QuantLib {
         */
         static Real bps(const Leg& leg,
                         const InterestRate& yield,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         static Real bps(const Leg& leg,
@@ -253,7 +253,7 @@ namespace QuantLib {
                         const DayCounter& dayCounter,
                         Compounding compounding,
                         Frequency frequency,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         //! Implied internal rate of return.
@@ -266,7 +266,7 @@ namespace QuantLib {
                           const DayCounter& dayCounter,
                           Compounding compounding,
                           Frequency frequency,
-                          bool includeSettlementDateFlows,
+                          const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                           Date settlementDate = Date(),
                           Date npvDate = Date(),
                           Real accuracy = 1.0e-10,
@@ -280,7 +280,7 @@ namespace QuantLib {
                           const DayCounter& dayCounter,
                           Compounding compounding,
                           Frequency frequency,
-                          bool includeSettlementDateFlows,
+                          const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                           Date settlementDate = Date(),
                           Date npvDate = Date(),
                           Real accuracy = 1.0e-10,
@@ -318,7 +318,7 @@ namespace QuantLib {
         static Time duration(const Leg& leg,
                              const InterestRate& yield,
                              Duration::Type type,
-                             bool includeSettlementDateFlows,
+                             const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                              Date settlementDate = Date(),
                              Date npvDate = Date());
         static Time duration(const Leg& leg,
@@ -327,7 +327,7 @@ namespace QuantLib {
                              Compounding compounding,
                              Frequency frequency,
                              Duration::Type type,
-                             bool includeSettlementDateFlows,
+                             const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                              Date settlementDate = Date(),
                              Date npvDate = Date());
 
@@ -341,7 +341,7 @@ namespace QuantLib {
         */
         static Real convexity(const Leg& leg,
                               const InterestRate& yield,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                               Date settlementDate = Date(),
                               Date npvDate = Date());
         static Real convexity(const Leg& leg,
@@ -349,7 +349,7 @@ namespace QuantLib {
                               const DayCounter& dayCounter,
                               Compounding compounding,
                               Frequency frequency,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                               Date settlementDate = Date(),
                               Date npvDate = Date());
 
@@ -359,7 +359,7 @@ namespace QuantLib {
         */
         static Real basisPointValue(const Leg& leg,
                                     const InterestRate& yield,
-                                    bool includeSettlementDateFlows,
+                                    const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                     Date settlementDate = Date(),
                                     Date npvDate = Date());
         static Real basisPointValue(const Leg& leg,
@@ -367,7 +367,7 @@ namespace QuantLib {
                                     const DayCounter& dayCounter,
                                     Compounding compounding,
                                     Frequency frequency,
-                                    bool includeSettlementDateFlows,
+                                    const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                     Date settlementDate = Date(),
                                     Date npvDate = Date());
 
@@ -378,7 +378,7 @@ namespace QuantLib {
         */
         static Real yieldValueBasisPoint(const Leg& leg,
                                          const InterestRate& yield,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                          Date settlementDate = Date(),
                                          Date npvDate = Date());
         static Real yieldValueBasisPoint(const Leg& leg,
@@ -386,7 +386,7 @@ namespace QuantLib {
                                          const DayCounter& dayCounter,
                                          Compounding compounding,
                                          Frequency frequency,
-                                         bool includeSettlementDateFlows,
+                                         const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                                          Date settlementDate = Date(),
                                          Date npvDate = Date());
         //@}
@@ -409,7 +409,7 @@ namespace QuantLib {
                         const DayCounter& dayCounter,
                         Compounding compounding,
                         Frequency frequency,
-                        bool includeSettlementDateFlows,
+                        const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                         Date settlementDate = Date(),
                         Date npvDate = Date());
         //! implied Z-spread.
@@ -419,7 +419,7 @@ namespace QuantLib {
                               const DayCounter& dayCounter,
                               Compounding compounding,
                               Frequency frequency,
-                              bool includeSettlementDateFlows,
+                              const ext::optional<bool>& includeSettlementDateFlows = ext::nullopt,
                               Date settlementDate = Date(),
                               Date npvDate = Date(),
                               Real accuracy = 1.0e-10,
