@@ -23,6 +23,7 @@
 */
 
 #include <ql/cashflows/overnightindexedcouponpricer.hpp>
+#include <utility>
 
 namespace QuantLib {
 
@@ -42,20 +43,72 @@ namespace QuantLib {
         }
     }
 
-    void CompoundingOvernightIndexedCouponPricer::initialize(const FloatingRateCoupon& coupon) {
-        coupon_ = dynamic_cast<const OvernightIndexedCoupon*>(&coupon);
-        QL_ENSURE(coupon_, "wrong coupon type");
+    OvernightIndexedCouponPricer::OvernightIndexedCouponPricer(
+            Handle<OptionletVolatilityStructure> v,
+            const bool effectiveVolatilityInput)
+        : capletVol_(std::move(v)),
+          effectiveVolatilityInput_(effectiveVolatilityInput) {
+        registerWith(capletVol_);
     }
 
+    void OvernightIndexedCouponPricer::initialize(const FloatingRateCoupon& coupon) {
+        if (const auto *cfCoupon = dynamic_cast<const CappedFlooredOvernightIndexedCoupon*>(&coupon)) {
+            auto *underlying = cfCoupon->underlying().get();
+            QL_REQUIRE(underlying, "OvernightIndexedCouponPricer: CappedFlooredOvernightIndexedCoupon underlying coupon not defined");
+            coupon_ = cfCoupon->underlying().get();
+        } else if (const auto *onCoupon = dynamic_cast<const OvernightIndexedCoupon*>(&coupon)) {
+            coupon_ = onCoupon;
+        } else {
+            QL_FAIL("OvernightIndexedCouponPricer: unsupported coupon type");
+        }
+    }
+
+    bool OvernightIndexedCouponPricer::effectiveVolatilityInput() const {
+        return effectiveVolatilityInput_;
+    }
+
+    Real OvernightIndexedCouponPricer::effectiveCapletVolatility() const {
+        return effectiveCapletVolatility_;
+    }
+
+    Real OvernightIndexedCouponPricer::effectiveFloorletVolatility() const {
+        return effectiveFloorletVolatility_;
+    }
+    
+    CompoundingOvernightIndexedCouponPricer::CompoundingOvernightIndexedCouponPricer(
+            Handle<OptionletVolatilityStructure> v,
+            const bool effectiveVolatilityInput)
+        : OvernightIndexedCouponPricer(std::move(v), effectiveVolatilityInput) {}
+
     Rate CompoundingOvernightIndexedCouponPricer::swapletRate() const {
-        return averageRate(coupon_->accrualEndDate());
+        auto [swapletRate, effectiveSpread, effectiveIndexFixing] = compute(coupon_->accrualEndDate());
+        swapletRate_ = swapletRate;
+        effectiveSpread_ = effectiveSpread;
+        effectiveIndexFixing_ = effectiveIndexFixing;
+        return swapletRate;
     }
 
     Rate CompoundingOvernightIndexedCouponPricer::averageRate(const Date& date) const {
-        const Date today = Settings::instance().evaluationDate();
+        auto [rate, effectiveSpread, effectiveIndexFixing] = compute(date);
+        return rate;
+    }
 
-        const ext::shared_ptr<OvernightIndex> index =
-            ext::dynamic_pointer_cast<OvernightIndex>(coupon_->index());
+    Rate CompoundingOvernightIndexedCouponPricer::effectiveSpread() const {
+        auto [r, effectiveSpread, effectiveIndexFixing] = compute(coupon_->accrualEndDate());
+        effectiveSpread_ = effectiveSpread;
+        return effectiveSpread_;
+    }
+
+    Rate CompoundingOvernightIndexedCouponPricer::effectiveIndexFixing() const {
+        auto [r, effectiveSpread, effectiveIndexFixing] = compute(coupon_->accrualEndDate());
+        effectiveIndexFixing_ = effectiveIndexFixing;
+        return effectiveIndexFixing_;
+    }
+
+    std::tuple<Rate, Spread, Rate> CompoundingOvernightIndexedCouponPricer::compute(const Date& date) const {
+	    const Date today = Settings::instance().evaluationDate();
+
+        const ext::shared_ptr<OvernightIndex> index = ext::dynamic_pointer_cast<OvernightIndex>(coupon_->index());
         const auto& pastFixings = index->timeSeries();
 
         const auto& fixingDates = coupon_->fixingDates();
@@ -63,21 +116,26 @@ namespace QuantLib {
         const auto& interestDates = coupon_->interestDates();
         const auto& dt = coupon_->dt();
         const bool applyObservationShift = coupon_->applyObservationShift();
+	    Real couponSpread = coupon_->spread();
 
         Size i = 0;
         const Size n = determineNumberOfFixings(interestDates, date, applyObservationShift);
 
-        Real compoundFactor = 1.0;
+        Real compoundFactor = 1.0, compoundFactorWithoutSpread = 1.0;
 
         // already fixed part
         while (i < n && fixingDates[i] < today) {
             // rate must have been fixed
-            const Rate fixing = pastFixings[fixingDates[i]];
+            Rate fixing = pastFixings[fixingDates[i]];
             QL_REQUIRE(fixing != Null<Real>(),
                        "Missing " << index->name() << " fixing for " << fixingDates[i]);
             Time span = (date >= interestDates[i + 1] ?
                              dt[i] :
                              index->dayCounter().yearFraction(interestDates[i], date));
+            if (coupon_->compoundSpreadDaily()) {
+                compoundFactorWithoutSpread *= (1.0 + fixing * span);
+                fixing += coupon_->spread();
+            }
             compoundFactor *= (1.0 + fixing * span);
             ++i;
         }
@@ -91,6 +149,10 @@ namespace QuantLib {
                     Time span = (date >= interestDates[i + 1] ?
                                      dt[i] :
                                      index->dayCounter().yearFraction(interestDates[i], date));
+                    if (coupon_->compoundSpreadDaily()) {
+                        compoundFactorWithoutSpread *= (1.0 + fixing * span);
+                        fixing += coupon_->spread();
+                    }
                     compoundFactor *= (1.0 + fixing * span);
                     ++i;
                 } else {
@@ -110,12 +172,13 @@ namespace QuantLib {
                        "null term structure set to this instance of " << index->name());
 
             const auto effectiveRate = [&index, &fixingDates, &date, &interestDates,
-                                        &dt](Size position) {
+                                        &dt, &couponSpread](Size position, bool compoundSpreadDaily) {
                 Rate fixing = index->fixing(fixingDates[position]);
                 Time span = (date >= interestDates[position + 1] ?
                                  dt[position] :
                                  index->dayCounter().yearFraction(interestDates[position], date));
-                return span * fixing;
+                Spread spreadToAdd = compoundSpreadDaily ? couponSpread : 0.0;
+                return span * (fixing + spreadToAdd);
             };
 
             if (!coupon_->canApplyTelescopicFormula()) {
@@ -130,7 +193,8 @@ namespace QuantLib {
                 // Same applies to a case when accrual calculation date does or
                 // does not occur on an interest date.
                 while (i < n) {
-                    compoundFactor *= (1.0 + effectiveRate(i));
+		            compoundFactorWithoutSpread *= (1.0 + effectiveRate(i, false));
+                    compoundFactor *= (1.0 + effectiveRate(i, coupon_->compoundSpreadDaily()));
                     ++i;
                 }
             } else {
@@ -148,6 +212,7 @@ namespace QuantLib {
                     const DiscountFactor endDiscount =
                         curve->discount(valueDates[std::min<Size>(nLockout, n)]);
                     compoundFactor *= startDiscount / endDiscount;
+                    compoundFactorWithoutSpread *= startDiscount / endDiscount;
                     // For the lockout periods the telescopic formula does not apply.
                     // The value dates (at which the projection is calculated) correspond
                     // to the locked-out fixing, while the interest dates (at which the
@@ -157,7 +222,8 @@ namespace QuantLib {
 
                     // With no lockout, the loop is skipped because i = n.
                     while (i < n) {
-                        compoundFactor *= (1.0 + effectiveRate(i));
+                        compoundFactorWithoutSpread *= (1.0 + effectiveRate(i, false));
+                        compoundFactor *= (1.0 + effectiveRate(i, coupon_->compoundSpreadDaily()));
                         ++i;
                     }
                 } else {
@@ -167,19 +233,29 @@ namespace QuantLib {
                     // previous date, then we'll add the missing bit.
                     const DiscountFactor endDiscount = curve->discount(valueDates[n - 1]);
                     compoundFactor *= startDiscount / endDiscount;
-                    compoundFactor *= (1.0 + effectiveRate(n - 1));
+                    compoundFactorWithoutSpread *= startDiscount / endDiscount;
+                    compoundFactor *= (1.0 + effectiveRate(n - 1, coupon_->compoundSpreadDaily()));
+                    compoundFactorWithoutSpread *= (1.0 + effectiveRate(n - 1, false));
                 }
             }
         }
 
+        const Rate tau = index->dayCounter().yearFraction(valueDates.front(), valueDates.back());
         const Rate rate = (compoundFactor - 1.0) / coupon_->accruedPeriod(date);
-        return coupon_->gearing() * rate + coupon_->spread();
-    }
+        Rate swapletRate = coupon_->gearing() * rate;
+        Spread effectiveSpread;
+        Rate effectiveIndexFixing;
+        
+        if (!coupon_->compoundSpreadDaily()) {
+            swapletRate += coupon_->spread();
+            effectiveSpread = coupon_->spread();
+            effectiveIndexFixing = rate;
+        } else {
+            effectiveSpread = rate - (compoundFactorWithoutSpread - 1.0) / tau;
+            effectiveIndexFixing = rate - effectiveSpread;
+        }
 
-    void
-    ArithmeticAveragedOvernightIndexedCouponPricer::initialize(const FloatingRateCoupon& coupon) {
-        coupon_ = dynamic_cast<const OvernightIndexedCoupon*>(&coupon);
-        QL_ENSURE(coupon_, "wrong coupon type");
+        return std::make_tuple(swapletRate, effectiveSpread, effectiveIndexFixing);
     }
 
     Rate ArithmeticAveragedOvernightIndexedCouponPricer::swapletRate() const {
