@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -24,12 +24,12 @@
 #ifndef quantlib_vanna_volga_double_barrier_engine_hpp
 #define quantlib_vanna_volga_double_barrier_engine_hpp
 
-#include <ql/experimental/barrieroption/doublebarrieroption.hpp>
+#include <ql/instruments/doublebarrieroption.hpp>
 #include <ql/experimental/barrieroption/vannavolgainterpolation.hpp>
-#include <ql/experimental/fx/blackdeltacalculator.hpp>
-#include <ql/experimental/fx/deltavolquote.hpp>
+#include <ql/quotes/deltavolquote.hpp>
 #include <ql/math/matrix.hpp>
 #include <ql/pricingengines/barrier/analyticbarrierengine.hpp>
+#include <ql/pricingengines/blackdeltacalculator.hpp>
 #include <ql/pricingengines/blackformula.hpp>
 #include <ql/processes/blackscholesprocess.hpp>
 #include <ql/quotes/simplequote.hpp>
@@ -164,7 +164,7 @@ namespace QuantLib {
                          adaptVanDelta_ ? bsPriceWithSmile_ : vanillaOption;
                      results_.additionalResults["BarrierInPrice"] =
                          adaptVanDelta_ ? bsPriceWithSmile_ : vanillaOption;
-                     results_.additionalResults["BarrierOutPrice"] = 0.0;
+                     results_.additionalResults["BarrierOutPrice"] = Real(0.0);
                  }
                  // already in
                  else if ((x0Quote->value() > arguments_.barrier_hi ||
@@ -175,7 +175,7 @@ namespace QuantLib {
                          adaptVanDelta_ ? bsPriceWithSmile_ : vanillaOption;
                      results_.additionalResults["BarrierInPrice"] =
                          adaptVanDelta_ ? bsPriceWithSmile_ : vanillaOption;
-                     results_.additionalResults["BarrierOutPrice"] = 0.0;
+                     results_.additionalResults["BarrierOutPrice"] = Real(0.0);
                  } else {
 
                      // set up BS barrier option pricing
