@@ -31,7 +31,7 @@
 #include <ql/experimental/credit/defaultlossmodel.hpp>
 #include <ql/experimental/credit/basket.hpp>
 #include <ql/experimental/math/latentmodel.hpp>
-#include <ql/functional.hpp>
+#include <functional>
 #include <numeric>
 
 /* Intended to replace GaussianLHPCDOEngine in 
