@@ -22,8 +22,8 @@
 
 #include <ql/errors.hpp>
 #include <ql/experimental/math/convolvedstudentt.hpp>
-#include <ql/functional.hpp>
 #include <boost/math/distributions/students_t.hpp>
+#include <functional>
 #include <vector>
 
 namespace QuantLib {
