@@ -29,7 +29,7 @@
 #include <ql/math/interpolations/lagrangeinterpolation.hpp>
 #include <ql/math/matrix.hpp>
 #include <ql/time/date.hpp>
-#include <ql/functional.hpp>
+#include <functional>
 
 namespace QuantLib {
     /*! References:
