@@ -29,7 +29,7 @@
 #include <ql/math/interpolations/lagrangeinterpolation.hpp>
 #include <ql/math/matrix.hpp>
 #include <ql/experimental/math/gaussiannoncentralchisquaredpolynomial.hpp>
-#include <ql/functional.hpp>
+#include <functional>
 #include <map>
 
 namespace QuantLib {
