@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2021 Marcin Rybacki
+ Copyright (C) 2025 Uzair Beg
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -21,6 +22,7 @@
 #include <ql/cashflows/iborcoupon.hpp>
 #include <ql/cashflows/cashflows.hpp>
 #include <ql/cashflows/simplecashflow.hpp>
+#include <ql/cashflows/fixedratecoupon.hpp>
 #include <ql/experimental/termstructures/crosscurrencyratehelpers.hpp>
 #include <ql/utilities/null_deleter.hpp>
 #include <utility>
@@ -29,6 +31,8 @@ namespace QuantLib {
 
     namespace {
 
+        constexpr double sample_fixed_rate = 0.01;
+
         Schedule legSchedule(const Date& evaluationDate,
                              const Period& tenor,
                              const Period& frequency,
@@ -81,8 +85,28 @@ namespace QuantLib {
             return IborLeg(sch, idx).withNotionals(1.0).withPaymentLag(paymentLag);
         }
 
+        Leg buildFixedLeg(const Date& evaluationDate,
+                          const Period& tenor,
+                          Natural fixingDays,
+                          const Calendar& calendar,
+                          BusinessDayConvention convention,
+                          bool endOfMonth,
+                          Frequency paymentFrequency,
+                          const DayCounter& dayCount,
+                          Integer paymentLag) {
+
+            auto freqPeriod = Period(paymentFrequency);
+
+            Schedule sch = legSchedule(evaluationDate, tenor, freqPeriod, fixingDays, calendar,
+                                       convention, endOfMonth);
+            return FixedRateLeg(sch)
+                .withNotionals(1.0)
+                .withCouponRates(sample_fixed_rate, dayCount)
+                .withPaymentLag(paymentLag);
+        }
+
         std::pair<Real, Real>
-        npvbpsConstNotionalLeg(const Leg& iborLeg,
+        npvbpsConstNotionalLeg(const Leg& leg,
                                const Date& initialNotionalExchangeDate,
                                const Date& finalNotionalExchangeDate,
                                const Handle<YieldTermStructure>& discountCurveHandle) {
@@ -90,7 +114,7 @@ namespace QuantLib {
             Date refDt = discountCurveHandle->referenceDate();
             const YieldTermStructure& discountRef = **discountCurveHandle;
             bool includeSettleDtFlows = true;
-            auto [npv, bps] = CashFlows::npvbps(iborLeg, discountRef, includeSettleDtFlows, refDt, refDt);
+            auto [npv, bps] = CashFlows::npvbps(leg, discountRef, includeSettleDtFlows, refDt, refDt);
             // Include NPV of the notional exchange at start and maturity.
             npv += (-1.0) * discountRef.discount(initialNotionalExchangeDate);
             npv += discountRef.discount(finalNotionalExchangeDate);
@@ -187,6 +211,58 @@ namespace QuantLib {
         }
     }
 
+
+    CrossCurrencySwapRateHelperBase::CrossCurrencySwapRateHelperBase(
+        const Handle<Quote>& quote,
+        const Period& tenor,
+        Natural fixingDays,
+        Calendar calendar,
+        BusinessDayConvention convention,
+        bool endOfMonth,
+        Handle<YieldTermStructure> collateralCurve,
+        Integer paymentLag)
+    : RelativeDateRateHelper(quote), tenor_(tenor), fixingDays_(fixingDays),
+      calendar_(std::move(calendar)), convention_(convention), endOfMonth_(endOfMonth),
+      paymentLag_(paymentLag), collateralHandle_(std::move(collateralCurve)) {
+        registerWith(collateralHandle_);
+    }
+
+    void CrossCurrencySwapRateHelperBase::setTermStructure(YieldTermStructure* t) {
+        // do not set the relinkable handle as an observer -
+        // force recalculation when needed
+        bool observer = false;
+
+        ext::shared_ptr<YieldTermStructure> temp(t, null_deleter());
+        termStructureHandle_.linkTo(temp, observer);
+
+        RelativeDateRateHelper::setTermStructure(t);
+    }
+
+    void CrossCurrencySwapRateHelperBase::initializeDatesFromLegs(const Leg& firstLeg,
+                                                                  const Leg& secondLeg) {
+        earliestDate_ = std::min(CashFlows::startDate(firstLeg),
+                                 CashFlows::startDate(secondLeg));
+
+        maturityDate_ = std::max(CashFlows::maturityDate(firstLeg),
+                                 CashFlows::maturityDate(secondLeg));
+
+        if (paymentLag_ == 0) {
+            initialNotionalExchangeDate_ = earliestDate_;
+            finalNotionalExchangeDate_   = maturityDate_;
+        } else {
+            initialNotionalExchangeDate_ = calendar_.advance(earliestDate_, paymentLag_, Days, convention_);
+            finalNotionalExchangeDate_   = calendar_.advance(maturityDate_, paymentLag_, Days, convention_);
+        }
+
+        Date lastPaymentDate =
+            std::max(firstLeg.back()->date(),
+                     secondLeg.back()->date());
+
+        latestRelevantDate_ = latestDate_ = std::max(maturityDate_, lastPaymentDate);
+    }
+
+
+
     CrossCurrencyBasisSwapRateHelperBase::CrossCurrencyBasisSwapRateHelperBase(
         const Handle<Quote>& basis,
         const Period& tenor,
@@ -201,64 +277,38 @@ namespace QuantLib {
         bool isBasisOnFxBaseCurrencyLeg,
         Frequency paymentFrequency,
         Integer paymentLag)
-    : RelativeDateRateHelper(basis), tenor_(tenor), fixingDays_(fixingDays),
-      calendar_(std::move(calendar)), convention_(convention), endOfMonth_(endOfMonth),
+    : CrossCurrencySwapRateHelperBase(basis, tenor, fixingDays, std::move(calendar), convention, endOfMonth,
+                                      std::move(collateralCurve), paymentLag),
       baseCcyIdx_(std::move(baseCurrencyIndex)), quoteCcyIdx_(std::move(quoteCurrencyIndex)),
-      collateralHandle_(std::move(collateralCurve)),
       isFxBaseCurrencyCollateralCurrency_(isFxBaseCurrencyCollateralCurrency),
       isBasisOnFxBaseCurrencyLeg_(isBasisOnFxBaseCurrencyLeg),
-      paymentFrequency_(paymentFrequency), paymentLag_(paymentLag) {
+      paymentFrequency_(paymentFrequency) {
         registerWith(baseCcyIdx_);
         registerWith(quoteCcyIdx_);
-        registerWith(collateralHandle_);
+
         CrossCurrencyBasisSwapRateHelperBase::initializeDates();
     }
 
     void CrossCurrencyBasisSwapRateHelperBase::initializeDates() {
         baseCcyIborLeg_ = buildFloatingLeg(evaluationDate_, tenor_, fixingDays_, calendar_, convention_,
-                                       endOfMonth_, baseCcyIdx_, paymentFrequency_, paymentLag_);
+                                           endOfMonth_, baseCcyIdx_, paymentFrequency_, paymentLag_);
+
         quoteCcyIborLeg_ = buildFloatingLeg(evaluationDate_, tenor_, fixingDays_, calendar_,
-                                        convention_, endOfMonth_, quoteCcyIdx_, paymentFrequency_, paymentLag_);
-        earliestDate_ = std::min(CashFlows::startDate(baseCcyIborLeg_), 
-                                CashFlows::startDate(quoteCcyIborLeg_));
-        maturityDate_ = std::max(CashFlows::maturityDate(baseCcyIborLeg_),
-                                 CashFlows::maturityDate(quoteCcyIborLeg_));
-        if (paymentLag_ == 0) {
-            initialNotionalExchangeDate_ = earliestDate_;
-            finalNotionalExchangeDate_ = maturityDate_;
-        } else {
-            initialNotionalExchangeDate_ = calendar_.advance(earliestDate_, paymentLag_, Days, convention_);
-            finalNotionalExchangeDate_ = calendar_.advance(maturityDate_, paymentLag_, Days, convention_);
-        }
-        Date lastPaymentDate = std::max(baseCcyIborLeg_.back()->date(), quoteCcyIborLeg_.back()->date());
-        latestRelevantDate_ = latestDate_ = std::max(maturityDate_, lastPaymentDate);
+                                            convention_, endOfMonth_, quoteCcyIdx_, paymentFrequency_, paymentLag_);
+
+        initializeDatesFromLegs(baseCcyIborLeg_, quoteCcyIborLeg_);
     }
 
     const Handle<YieldTermStructure>&
     CrossCurrencyBasisSwapRateHelperBase::baseCcyLegDiscountHandle() const {
-        QL_REQUIRE(!termStructureHandle_.empty(), "term structure not set");
-        QL_REQUIRE(!collateralHandle_.empty(), "collateral term structure not set");
         return isFxBaseCurrencyCollateralCurrency_ ? collateralHandle_ : termStructureHandle_;
     }
 
     const Handle<YieldTermStructure>&
     CrossCurrencyBasisSwapRateHelperBase::quoteCcyLegDiscountHandle() const {
-        QL_REQUIRE(!termStructureHandle_.empty(), "term structure not set");
-        QL_REQUIRE(!collateralHandle_.empty(), "collateral term structure not set");
         return isFxBaseCurrencyCollateralCurrency_ ? termStructureHandle_ : collateralHandle_;
     }
 
-    void CrossCurrencyBasisSwapRateHelperBase::setTermStructure(YieldTermStructure* t) {
-        // do not set the relinkable handle as an observer -
-        // force recalculation when needed
-        bool observer = false;
-
-        ext::shared_ptr<YieldTermStructure> temp(t, null_deleter());
-        termStructureHandle_.linkTo(temp, observer);
-
-        RelativeDateRateHelper::setTermStructure(t);
-    }
-
     ConstNotionalCrossCurrencyBasisSwapRateHelper::ConstNotionalCrossCurrencyBasisSwapRateHelper(
         const Handle<Quote>& basis,
         const Period& tenor,
@@ -288,9 +338,16 @@ namespace QuantLib {
                                            paymentLag) {}
 
     Real ConstNotionalCrossCurrencyBasisSwapRateHelper::impliedQuote() const {
+        QL_REQUIRE(!termStructureHandle_.empty(), "term structure not set");
+        QL_REQUIRE(!collateralHandle_.empty(), "collateral term structure not set");
+
         auto [npvBaseCcy, bpsBaseCcy] = npvbpsConstNotionalLeg(baseCcyIborLeg_, initialNotionalExchangeDate_, finalNotionalExchangeDate_, baseCcyLegDiscountHandle());
         auto [npvQuoteCcy, bpsQuoteCcy] = npvbpsConstNotionalLeg(quoteCcyIborLeg_, initialNotionalExchangeDate_, finalNotionalExchangeDate_, quoteCcyLegDiscountHandle());
+
         Real bps = isBasisOnFxBaseCurrencyLeg_ ? -bpsBaseCcy : bpsQuoteCcy;
+
+        QL_REQUIRE(std::fabs(bps) > 0.0, "null BPS");
+
         return -(npvQuoteCcy - npvBaseCcy) / bps;
     }
 
@@ -302,6 +359,7 @@ namespace QuantLib {
             RateHelper::accept(v);
     }
 
+
     MtMCrossCurrencyBasisSwapRateHelper::MtMCrossCurrencyBasisSwapRateHelper(
         const Handle<Quote>& basis,
         const Period& tenor,
@@ -333,26 +391,27 @@ namespace QuantLib {
       isFxBaseCurrencyLegResettable_(isFxBaseCurrencyLegResettable) {}
 
     Real MtMCrossCurrencyBasisSwapRateHelper::impliedQuote() const {
-        Real npvBaseCcy = 0.0, bpsBaseCcy = 0.0;
-        Real npvQuoteCcy = 0.0, bpsQuoteCcy = 0.0;
-        if (isFxBaseCurrencyLegResettable_) {
-            std::tie(npvBaseCcy, bpsBaseCcy) =
+        QL_REQUIRE(!termStructureHandle_.empty(), "term structure not set");
+        QL_REQUIRE(!collateralHandle_.empty(), "collateral term structure not set");
+
+        auto [npvBaseCcy, bpsBaseCcy] =
+            isFxBaseCurrencyLegResettable_ ?
                 npvbpsResettingLeg(baseCcyIborLeg_, paymentLag_, calendar_, convention_,
-                                   baseCcyLegDiscountHandle(), quoteCcyLegDiscountHandle());
-            std::tie(npvQuoteCcy, bpsQuoteCcy) =
-                npvbpsConstNotionalLeg(quoteCcyIborLeg_, initialNotionalExchangeDate_,
-                                       finalNotionalExchangeDate_, quoteCcyLegDiscountHandle());
-        } else {
-            std::tie(npvBaseCcy, bpsBaseCcy) =
+                                   baseCcyLegDiscountHandle(), quoteCcyLegDiscountHandle()) :
                 npvbpsConstNotionalLeg(baseCcyIborLeg_, initialNotionalExchangeDate_,
                                        finalNotionalExchangeDate_, baseCcyLegDiscountHandle());
-            std::tie(npvQuoteCcy, bpsQuoteCcy) = npvbpsResettingLeg(
-                                       quoteCcyIborLeg_, paymentLag_, calendar_, convention_,
-                                       quoteCcyLegDiscountHandle(), baseCcyLegDiscountHandle());
-        }
+
+        auto [npvQuoteCcy, bpsQuoteCcy] =
+            isFxBaseCurrencyLegResettable_ ?
+                npvbpsConstNotionalLeg(quoteCcyIborLeg_, initialNotionalExchangeDate_,
+                                       finalNotionalExchangeDate_, quoteCcyLegDiscountHandle()) :
+                npvbpsResettingLeg(quoteCcyIborLeg_, paymentLag_, calendar_, convention_,
+                                   quoteCcyLegDiscountHandle(), baseCcyLegDiscountHandle());
 
         Real bps = isBasisOnFxBaseCurrencyLeg_ ? -bpsBaseCcy : bpsQuoteCcy;
 
+        QL_REQUIRE(std::fabs(bps) > 0.0, "null BPS");
+
         return -(npvQuoteCcy - npvBaseCcy) / bps;
     }
 
@@ -363,4 +422,75 @@ namespace QuantLib {
         else
             RateHelper::accept(v);
     }
+
+
+    ConstNotionalCrossCurrencySwapRateHelper::ConstNotionalCrossCurrencySwapRateHelper(
+        const Handle<Quote>& fixedRate,
+        const Period& tenor,
+        Natural fixingDays,
+        const Calendar& calendar,
+        BusinessDayConvention convention,
+        bool endOfMonth,
+        Frequency fixedFrequency,
+        DayCounter  fixedDayCount,
+        const ext::shared_ptr<IborIndex>& floatIndex,
+        const Handle<YieldTermStructure>& collateralCurve,
+        bool collateralOnFixedLeg,
+        Integer paymentLag)
+    : CrossCurrencySwapRateHelperBase(fixedRate, tenor, fixingDays, calendar, convention, endOfMonth,
+                                      collateralCurve, paymentLag),
+      fixedFrequency_(fixedFrequency),
+      fixedDayCount_(std::move(fixedDayCount)),
+      floatIndex_(floatIndex),
+      collateralOnFixedLeg_(collateralOnFixedLeg) {
+
+        QL_REQUIRE(floatIndex_, "floating index required");
+        registerWith(floatIndex_);
+
+        initializeDates();
+    }
+
+    void ConstNotionalCrossCurrencySwapRateHelper::initializeDates() {
+        fixedLeg_ = buildFixedLeg(evaluationDate_, tenor_, fixingDays_, calendar_, convention_,
+                                  endOfMonth_, fixedFrequency_, fixedDayCount_, paymentLag_);
+        floatLeg_ = buildFloatingLeg(evaluationDate_, tenor_, fixingDays_, floatIndex_->fixingCalendar(),
+                                     floatIndex_->businessDayConvention(), endOfMonth_,
+                                     floatIndex_, floatIndex_->tenor().frequency(), paymentLag_);
+
+        initializeDatesFromLegs(fixedLeg_, floatLeg_);
+    }
+
+    const Handle<YieldTermStructure>&
+    ConstNotionalCrossCurrencySwapRateHelper::fixedLegDiscountHandle() const {
+        return collateralOnFixedLeg_ ? collateralHandle_ : termStructureHandle_;
+    }
+
+    const Handle<YieldTermStructure>&
+    ConstNotionalCrossCurrencySwapRateHelper::floatingLegDiscountHandle() const {
+        return collateralOnFixedLeg_ ? termStructureHandle_ : collateralHandle_;
+    }
+
+    Real ConstNotionalCrossCurrencySwapRateHelper::impliedQuote() const {
+        QL_REQUIRE(!termStructureHandle_.empty(), "term structure not set");
+        QL_REQUIRE(!collateralHandle_.empty(), "collateral term structure not set");
+
+        auto [fixedNpv, fixedBps] = npvbpsConstNotionalLeg(
+            fixedLeg_, initialNotionalExchangeDate_, finalNotionalExchangeDate_, fixedLegDiscountHandle());
+
+        auto [floatNpv, floatBps] = npvbpsConstNotionalLeg(
+            floatLeg_, initialNotionalExchangeDate_, finalNotionalExchangeDate_, floatingLegDiscountHandle());
+
+        QL_REQUIRE(std::fabs(fixedBps) > 0.0, "null fixed-leg BPS");
+
+        return sample_fixed_rate + (floatNpv - fixedNpv) / fixedBps;
+    }
+
+    void ConstNotionalCrossCurrencySwapRateHelper::accept(AcyclicVisitor& v) {
+        auto* v1 = dynamic_cast<Visitor<ConstNotionalCrossCurrencySwapRateHelper>*>(&v);
+        if (v1 != nullptr)
+            v1->visit(*this);
+        else
+            RateHelper::accept(v);
+    }
+
 }
