@@ -2,6 +2,7 @@
 
 /*
  Copyright (C) 2021 Marcin Rybacki
+ Copyright (C) 2025 Uzair Beg
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -28,13 +29,40 @@
 
 namespace QuantLib {
 
-    //! Base class for cross-currency basis swap rate helpers
-    class CrossCurrencyBasisSwapRateHelperBase : public RelativeDateRateHelper {
+    class CrossCurrencySwapRateHelperBase : public RelativeDateRateHelper {
       public:
-        //! \name RateHelper interface
-        //@{
-        void setTermStructure(YieldTermStructure*) override;
-        //@}
+        void setTermStructure(YieldTermStructure* t) override;
+
+      protected:
+        CrossCurrencySwapRateHelperBase(const Handle<Quote>& quote,
+                                        const Period& tenor,
+                                        Natural fixingDays,
+                                        Calendar calendar,
+                                        BusinessDayConvention convention,
+                                        bool endOfMonth,
+                                        Handle<YieldTermStructure> collateralCurve,
+                                        Integer paymentLag);
+
+        void initializeDatesFromLegs(const Leg& firstLeg, const Leg& secondLeg);
+
+        Period tenor_;
+        Natural fixingDays_;
+        Calendar calendar_;
+        BusinessDayConvention convention_;
+        bool endOfMonth_;
+        Integer paymentLag_;
+
+        Handle<YieldTermStructure> collateralHandle_;
+
+        RelinkableHandle<YieldTermStructure> termStructureHandle_;
+
+        Date initialNotionalExchangeDate_;
+        Date finalNotionalExchangeDate_;
+    };
+
+
+    //! Base class for cross-currency basis swap rate helpers
+    class CrossCurrencyBasisSwapRateHelperBase : public CrossCurrencySwapRateHelperBase {
       protected:
         CrossCurrencyBasisSwapRateHelperBase(const Handle<Quote>& basis,
                                              const Period& tenor,
@@ -54,28 +82,17 @@ namespace QuantLib {
         const Handle<YieldTermStructure>& baseCcyLegDiscountHandle() const;
         const Handle<YieldTermStructure>& quoteCcyLegDiscountHandle() const;
 
-        Period tenor_;
-        Natural fixingDays_;
-        Calendar calendar_;
-        BusinessDayConvention convention_;
-        bool endOfMonth_;
         ext::shared_ptr<IborIndex> baseCcyIdx_;
         ext::shared_ptr<IborIndex> quoteCcyIdx_;
-        Handle<YieldTermStructure> collateralHandle_;
         bool isFxBaseCurrencyCollateralCurrency_;
         bool isBasisOnFxBaseCurrencyLeg_;
         Frequency paymentFrequency_;
-        Integer paymentLag_;
 
         Leg baseCcyIborLeg_;
         Leg quoteCcyIborLeg_;
-
-        Date initialNotionalExchangeDate_;
-        Date finalNotionalExchangeDate_;
-
-        RelinkableHandle<YieldTermStructure> termStructureHandle_;
     };
 
+
     //! Rate helper for bootstrapping over constant-notional cross-currency basis swaps
     /*!
     Unlike marked-to-market cross currency swaps, both notionals
@@ -165,6 +182,50 @@ namespace QuantLib {
       private:
         bool isFxBaseCurrencyLegResettable_;
     };
+
+
+    //! Rate helper for bootstrapping fixed–vs-floating cross-currency par swaps
+    /*!
+    This helper represents a par cross-currency swap exchanging a fixed-rate leg
+    against a floating-rate leg in a different currency. Since the swap is quoted
+    at par, the FX spot cancels out and is not required.
+
+    The collateralOnFixedLeg flag determines which leg is discounted using the provided
+    collateral curve, while the other leg’s discount curve is the one being bootstrapped.
+    */
+    class ConstNotionalCrossCurrencySwapRateHelper : public CrossCurrencySwapRateHelperBase {
+      public:
+        ConstNotionalCrossCurrencySwapRateHelper(
+            const Handle<Quote>& fixedRate,
+            const Period& tenor,
+            Natural fixingDays,
+            const Calendar& calendar,
+            BusinessDayConvention convention,
+            bool endOfMonth,
+            Frequency fixedFrequency,
+            DayCounter  fixedDayCount,
+            const ext::shared_ptr<IborIndex>& floatIndex,
+            const Handle<YieldTermStructure>& collateralCurve,
+            bool collateralOnFixedLeg,
+            Integer paymentLag = 0);
+
+        Real impliedQuote() const override;
+        void accept(AcyclicVisitor&) override;
+
+      protected:
+        void initializeDates() override;
+        const Handle<YieldTermStructure>& fixedLegDiscountHandle() const;
+        const Handle<YieldTermStructure>& floatingLegDiscountHandle() const;
+
+        Frequency fixedFrequency_;
+        DayCounter fixedDayCount_;
+        ext::shared_ptr<IborIndex> floatIndex_;
+        bool collateralOnFixedLeg_;
+
+        Leg fixedLeg_;
+        Leg floatLeg_;
+    };
+
 }
 
 #endif
