@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -47,8 +47,8 @@ namespace QuantLib {
                 China(China::IB), shiborConvention(tenor), false,
                 Actual360(), h) {}
     
-    boost::shared_ptr<IborIndex> Shibor::clone(
+    ext::shared_ptr<IborIndex> Shibor::clone(
                                   const Handle<YieldTermStructure>& h) const {
-        return boost::shared_ptr<IborIndex>(new Shibor(tenor(), h));
+        return ext::shared_ptr<IborIndex>(new Shibor(tenor(), h));
     }
 }
