@@ -3,6 +3,7 @@
 /*
  Copyright (C) 2003, 2004 Ferdinando Ametrano
  Copyright (C) 2007 StatPro Italia srl
+ Copyright (C) 2025 Kareem Fareed
 
  This file is part of QuantLib, a free-software/open-source library
  for financial quantitative analysts and developers - http://quantlib.org/
@@ -11,7 +12,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -147,7 +148,17 @@ namespace QuantLib {
         const ext::shared_ptr<StrikedTypePayoff>& payoff,
         const ext::shared_ptr<Exercise>& exercise)
     : OneAssetOption(payoff, exercise),
-      averageType_(averageType) {}
+      averageType_(averageType)
+      {}
+
+    ContinuousAveragingAsianOption::ContinuousAveragingAsianOption(
+        Average::Type averageType,
+        Date startDate,
+        const ext::shared_ptr<StrikedTypePayoff>& payoff,
+        const ext::shared_ptr<Exercise>& exercise)
+    : OneAssetOption(payoff, exercise),
+      averageType_(averageType),
+      startDate_(startDate) {}
 
     void ContinuousAveragingAsianOption::setupArguments(
                                        PricingEngine::arguments* args) const {
@@ -157,6 +168,7 @@ namespace QuantLib {
         auto* moreArgs = dynamic_cast<ContinuousAveragingAsianOption::arguments*>(args);
         QL_REQUIRE(moreArgs != nullptr, "wrong argument type");
         moreArgs->averageType = averageType_;
+        moreArgs->startDate = startDate_;
     }
 
     void ContinuousAveragingAsianOption::arguments::validate() const {
