@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -44,10 +44,7 @@ namespace QuantLib {
         //! Default constructor returning a null interest rate.
         InterestRate();
         //! Standard constructor
-        InterestRate(Rate r,
-                     const DayCounter& dc,
-                     Compounding comp,
-                     Frequency freq);
+        InterestRate(Rate r, DayCounter dc, Compounding comp, Frequency freq);
         //@}
         //! \name conversions
         //@{
