@@ -78,10 +78,10 @@ namespace QuantLib {
             templateImpl(const I1& xBegin, const I1& xEnd, const I2& yBegin,
                          const int requiredPoints = 2)
             : xBegin_(xBegin), xEnd_(xEnd), yBegin_(yBegin) {
-                QL_REQUIRE(static_cast<int>(xEnd_-xBegin_) >= requiredPoints,
+                QL_REQUIRE(static_cast<std::ptrdiff_t>(xEnd_-xBegin_) >= requiredPoints,
                            "not enough points to interpolate: at least " <<
                            requiredPoints <<
-                           " required, " << static_cast<int>(xEnd_-xBegin_)<< " provided");
+                           " required, " << static_cast<std::ptrdiff_t>(xEnd_-xBegin_)<< " provided");
             }
             Real xMin() const override { return *xBegin_; }
             Real xMax() const override { return *(xEnd_ - 1); }
