@@ -11,7 +11,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -33,8 +33,7 @@
 namespace QuantLib {
 
     namespace detail {
-        template<class I1, class I2, class I> class LogInterpolationImpl;
-        template<class I1, class I2, class IN1, class IN2> class LogMixedInterpolationImpl;
+        template <class I1, class I2> class LogInterpolationImpl;
     }
 
     //! %log-linear interpolation between discrete points
@@ -48,9 +47,8 @@ namespace QuantLib {
         template <class I1, class I2>
         LogLinearInterpolation(const I1& xBegin, const I1& xEnd,
                                const I2& yBegin) {
-            impl_ = ext::shared_ptr<Interpolation::Impl>(new
-                detail::LogInterpolationImpl<I1, I2, Linear>(xBegin, xEnd,
-                                                             yBegin));
+            impl_ = ext::make_shared<detail::LogInterpolationImpl<I1, I2>>(
+                xBegin, xEnd, yBegin, Linear());
             impl_->update();
         }
     };
@@ -82,12 +80,11 @@ namespace QuantLib {
                               Real leftConditionValue,
                               CubicInterpolation::BoundaryCondition rightC,
                               Real rightConditionValue) {
-            impl_ = ext::shared_ptr<Interpolation::Impl>(new
-                detail::LogInterpolationImpl<I1, I2, Cubic>(
-                    xBegin, xEnd, yBegin,
-                    Cubic(da, monotonic,
-                          leftC, leftConditionValue,
-                          rightC, rightConditionValue)));
+            impl_ = ext::make_shared<detail::LogInterpolationImpl<I1, I2>>(
+                xBegin, xEnd, yBegin,
+                Cubic(da, monotonic,
+                      leftC, leftConditionValue,
+                      rightC, rightConditionValue));
             impl_->update();
         }
     };
@@ -255,12 +252,11 @@ namespace QuantLib {
                                          Real leftConditionValue,
                                          CubicInterpolation::BoundaryCondition rightC,
                                          Real rightConditionValue) {
-            impl_ = ext::shared_ptr<Interpolation::Impl>(new
-                detail::LogInterpolationImpl<I1, I2, MixedLinearCubic>(
-                    xBegin, xEnd, yBegin,
-                    MixedLinearCubic(n, behavior, da, monotonic,
-                                     leftC, leftConditionValue,
-                                     rightC, rightConditionValue)));
+            impl_ = ext::make_shared<detail::LogInterpolationImpl<I1, I2>>(
+                xBegin, xEnd, yBegin,
+                MixedLinearCubic(n, behavior, da, monotonic,
+                                 leftC, leftConditionValue,
+                                 rightC, rightConditionValue));
             impl_->update();
         }
     };
@@ -353,21 +349,22 @@ namespace QuantLib {
 
     namespace detail {
 
-        template <class I1, class I2, class Interpolator>
+        template <class I1, class I2>
         class LogInterpolationImpl
-            : public Interpolation::templateImpl<I1,I2> {
+            : public Interpolation::templateImpl<I1, I2> {
           public:
+            template <class Interpolator>
             LogInterpolationImpl(const I1& xBegin, const I1& xEnd,
                                  const I2& yBegin,
-                                 const Interpolator& factory = Interpolator())
-            : Interpolation::templateImpl<I1,I2>(xBegin, xEnd, yBegin,
-                                                 Interpolator::requiredPoints),
+                                 const Interpolator& factory)
+            : Interpolation::templateImpl<I1, I2>(xBegin, xEnd, yBegin,
+                                                  Interpolator::requiredPoints),
               logY_(xEnd-xBegin) {
                 interpolation_ = factory.interpolate(this->xBegin_,
                                                      this->xEnd_,
                                                      logY_.begin());
             }
-            void update() {
+            void update() override {
                 for (Size i=0; i<logY_.size(); ++i) {
                     QL_REQUIRE(this->yBegin_[i]>0.0,
                                "invalid value (" << this->yBegin_[i]
@@ -376,19 +373,18 @@ namespace QuantLib {
                 }
                 interpolation_.update();
             }
-            Real value(Real x) const {
-                return std::exp(interpolation_(x, true));
-            }
-            Real primitive(Real) const {
+            Real value(Real x) const override { return std::exp(interpolation_(x, true)); }
+            Real primitive(Real) const override {
                 QL_FAIL("LogInterpolation primitive not implemented");
             }
-            Real derivative(Real x) const {
+            Real derivative(Real x) const override {
                 return value(x)*interpolation_.derivative(x, true);
             }
-            Real secondDerivative(Real x) const {
+            Real secondDerivative(Real x) const override {
                 return derivative(x)*interpolation_.derivative(x, true) +
                             value(x)*interpolation_.secondDerivative(x, true);
             }
+
           private:
             std::vector<Real> logY_;
             Interpolation interpolation_;
