@@ -28,7 +28,7 @@
 #define quantlib_linear_least_squares_regression_hpp
 
 #include <ql/math/generallinearleastsquares.hpp>
-#include <ql/functional.hpp>
+#include <functional>
 #include <type_traits>
 
 namespace QuantLib {
