@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -30,11 +30,11 @@
 
 namespace QuantLib {
 
-    //! transformed grid
-    /*! This package encapuslates an array of grid points.  It is used primarily
-     in PDE calculations.
+    /*! \deprecated Part of the old FD framework; copy this function
+                    in your codebase if needed.
+                    Deprecated in version 1.37.
     */
-    class TransformedGrid {
+    class [[deprecated("Part of the old FD framework; copy this function in your codebase if needed")]] TransformedGrid {
     public:
         TransformedGrid (const Array &grid) :
             grid_(grid), transformedGrid_(grid),
@@ -93,7 +93,14 @@ namespace QuantLib {
         Array dx_;
     };
 
-    class LogGrid : public TransformedGrid {
+
+    QL_DEPRECATED_DISABLE_WARNING
+
+    /*! \deprecated Part of the old FD framework; copy this function
+                    in your codebase if needed.
+                    Deprecated in version 1.37.
+    */
+    class [[deprecated("Part of the old FD framework; copy this function in your codebase if needed")]] LogGrid : public TransformedGrid {
     public:
         LogGrid(const Array &grid) :
             TransformedGrid(grid, [](Real x) -> Real { return std::log(x); }){};
@@ -101,6 +108,8 @@ namespace QuantLib {
         Real logGrid(Size i) const { return transformedGrid(i);}
     };
 
+    QL_DEPRECATED_ENABLE_WARNING
+
 }
 
 
