@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -46,15 +46,15 @@ namespace QuantLib {
 
         Size size() const override;
         void setTime(Time t1, Time t2) override;
-        Disposable<Array> apply(const Array& x) const override;
-        Disposable<Array> apply_mixed(const Array& x) const override;
+        Array apply(const Array& x) const override;
+        Array apply_mixed(const Array& x) const override;
 
-        Disposable<Array> apply_direction(Size direction, const Array& x) const override;
+        Array apply_direction(Size direction, const Array& x) const override;
 
-        Disposable<Array> solve_splitting(Size direction, const Array& x, Real s) const override;
-        Disposable<Array> preconditioner(const Array& r, Real s) const override;
+        Array solve_splitting(Size direction, const Array& x, Real s) const override;
+        Array preconditioner(const Array& r, Real s) const override;
 
-        Disposable<std::vector<SparseMatrix> > toMatrixDecomp() const override;
+        std::vector<SparseMatrix> toMatrixDecomp() const override;
 
       private:
         const ext::shared_ptr<FdmMesher> mesher_;
