@@ -49,9 +49,7 @@ namespace QuantLib {
               Handle<YieldTermStructure>(ext::make_shared<ZeroSpreadedTermStructure>(
                   batesProcess->dividendYield(),
                   Handle<Quote>(ext::shared_ptr<Quote>(new SimpleQuote(lambda_ * m_))),
-                  Continuous,
-                  NoFrequency,
-                  batesProcess->dividendYield()->dayCounter())),
+                  Continuous)),
               batesProcess->s0(),
               batesProcess->v0(),
               batesProcess->kappa(),
