@@ -26,7 +26,7 @@
 #define quantlib_numerical_differentiation_hpp
 
 #include <ql/math/array.hpp>
-#include <ql/functional.hpp>
+#include <functional>
 
 namespace QuantLib {
 
