@@ -10,7 +10,7 @@
  under the terms of the QuantLib license.  You should have received a
  copy of the license along with this program; if not, please email
  <quantlib-dev@lists.sf.net>. The license is also available online at
- <http://quantlib.org/license.shtml>.
+ <https://www.quantlib.org/license.shtml>.
 
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
@@ -50,8 +50,7 @@ namespace QuantLib {
 
       protected:
         //apply for QuantLib's Runge-Kutta implementation
-        Disposable<std::vector<Real> >
-            apply(Time, const std::vector<Real>&) const;
+        std::vector<Real> apply(Time, const std::vector<Real>&) const;
 
         Time dt_;
         const Real eps_, relInitStepSize_;
