@@ -90,8 +90,18 @@ namespace QuantLib {
         std::list<ext::shared_ptr<StepCondition<Array> > > stepConditions;
 
         if (!cashFlow.empty()) {
+            const Date maturityDate = exercise->lastDate();
+            DividendSchedule dividends;
+            std::copy_if(
+                cashFlow.begin(), cashFlow.end(),
+                std::back_inserter(dividends),
+                [refDate, maturityDate](const ext::shared_ptr<Dividend>& div) -> bool {
+                    return div->date() >= refDate && div->date() <= maturityDate;
+                }
+            );
+
             auto dividendCondition =
-                ext::make_shared<FdmDividendHandler>(cashFlow, mesher,
+                ext::make_shared<FdmDividendHandler>(dividends, mesher,
                                                      refDate, dayCounter, 0);
             stepConditions.push_back(dividendCondition);
 
